"use client"

import type { Locale } from "@repo/i18n/config"
import { Button } from "@repo/ui/design/Button"
import { Link } from "@repo/ui/design/Link"
import { Typography } from "@repo/ui/design/Typography"
import { useLocale } from "next-intl"
import { useState } from "react"
import {
  fromLocaleToWikipediaLocale,
  getWikipediaLink,
  getWikipediaPageInternalLinks,
} from "./wikipedia-api"

export const WikipediaClient: React.FC = () => {
  const [isLoading, setIsLoading] = useState(false)

  const localeCurrent = useLocale() as Locale
  const localeWikipedia = fromLocaleToWikipediaLocale(localeCurrent)

  const handleClick: React.MouseEventHandler<HTMLButtonElement> = async () => {
    setIsLoading(true)
    const fromPageInput = "Linux"
    const toPageInput = "Node.js"
    console.log({
      fromPageInput,
      toPageInput,
    })
    const [fromPageWikipediaLinks, toPageWikipediaLinks] = await Promise.all([
      getWikipediaPageInternalLinks({
        title: fromPageInput,
        locale: localeWikipedia,
      }),
      getWikipediaPageInternalLinks({
        title: toPageInput,
        locale: localeWikipedia,
      }),
    ])
    console.log({
      fromPageWikipediaLinks,
      toPageWikipediaLinks,
    })
    // const deepInternalLinks = await getDeepWikipediaPageInternalLinks({
    //   locale: localeWikipedia,
    //   data: {
    //     [fromPageWikipediaLinks.title]: fromPageWikipediaLinks,
    //     [toPageWikipediaLinks.title]: toPageWikipediaLinks,
    //   },
    // })
    // console.log(deepInternalLinks)
    setIsLoading(false)
  }

  return (
    <section className="my-6 flex items-center justify-center space-x-6">
      <Button onClick={handleClick} isLoading={isLoading} className="w-36">
        Wikipedia
      </Button>
      <Typography variant="text1" as="p">
        <span>Using: </span>
        <Link href={getWikipediaLink(localeWikipedia)} target="_blank">
          {getWikipediaLink(localeWikipedia).replace("https://", "")}
        </Link>
      </Typography>
    </section>
  )
}
